@@ -1,10 +1,9 @@
 from django.db import models
+from django.conf import settings
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
 
-from compat import AUTH_USER_MODEL
-
 class VoteManger(models.Manager):
     def filter(self, *args, **kwargs):
         if kwargs.has_key('content_object'):
@@ -17,7 +16,7 @@ class VoteManger(models.Manager):
         return super(VoteManger, self).filter(*args, **kwargs)
     
 class Vote(models.Model):
-    user = models.ForeignKey(AUTH_USER_MODEL)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL)
     content_type = models.ForeignKey(ContentType)
     object_id = models.PositiveIntegerField()
     content_object = generic.GenericForeignKey()
